/*
  $Id: FileAttachable.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;


/**
	A <code>FileAttachable</code> item is an item that can have
	a {@link File} attached to it.
	
	@author enell
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (Mon, 06 Apr 2009) $
*/
public interface FileAttachable
	extends Identifiable
{
	/**
		Get the file that is attached to the item.
		@return A <code>File</code> item, or null if no file is attached
		@throws PermissionDeniedException If the logged in user doesn't have 
			read permission for the file
		@throws BaseException If there is another error
	*/
	public File getFile()
		throws PermissionDeniedException, BaseException;

	/**
		Attach a file to the item.
		@param file The file to attach to the item
		@throws PermissionDeniedException If the logged in user doesn't 
			have use permission for the file or write permission for the
			item
		@throws BaseException If there is another error
	*/
	public void setFile(File file)
		throws PermissionDeniedException, BaseException;
}
