/*
	$Id: ItemInUseException.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

/**
	This exception is thrown when trying delete an item
	that is used (reference to) by some other item or items.

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (Mon, 06 Apr 2009) $
*/
public class ItemInUseException
	extends PermissionDeniedException
{

	/**
		
	*/
	private static final long serialVersionUID = 8687133796504091488L;

	/**
		Creates a new <code>ItemInUseException</code>. The error
		message produced will look like:
		<code>Permission denied. The item User[ID=325] is used by another item.</code>

		@param what A description of what already exists, for 
			example User[Id=325]
	*/
	public ItemInUseException(String what)
	{
		super("The item "+what+" is used by another item.");
	}
	
	/**
		Creates a new <code>ItemInUseException</code> with a cause. The error
		message produced will look like:
		<code>Permission denied. The item User[ID=325] is used by another item.</code>
	
		@param what A description of what already exists, for 
			example User[Id=325]
		@param cause The cause of the error
		@since 2.4
	*/
	public ItemInUseException(String what, Throwable cause)
	{
		super("The item "+what+" is used by another item.", cause);
	}
	
}
