/**
	$Id: ChangeHistoryDetailData.java 5071 2009-08-21 06:17:57Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	Represents a change (creation/update/deletion) made to a
	single entity in a transaction. Changes to multiple entities
	in a single transactions are grouped with a common reference
	to a {@link ChangeHistoryData} object.

	@author Nicklas
	@version 2.13
	@base.modified $Date: 2009-08-21 08:17:57 +0200 (Fri, 21 Aug 2009) $
	@hibernate.class table="`ChangeHistoryDetails`" lazy="false" mutable="false"
*/
public class ChangeHistoryDetailData
	extends BasicData
{

	public ChangeHistoryDetailData()
	{}
	
	private ChangeHistoryData history;
	/**
	 	Get the main history entry the details belong to.
	 	@hibernate.many-to-one column="`history_id`" not-null="true" 
	 		outer-join="false" update="false"
	*/
	public ChangeHistoryData getChangeHistory()
	{
		return history;
	}
	public void setChangeHistory(ChangeHistoryData history)
	{
		this.history = history;
	}

	private int changeType;
	/**
		The type of the change: 
		1 = create, 2 = update, 3 = delete
		@hibernate.property type="int"
		@hibernate.column name="`change_type`" not-null="true"
	*/
	public int getChangeType()
	{
		return changeType;
	}
	public void setChangeType(int changeType)
	{
		this.changeType = changeType;
	}
	
	private int itemId;
	/**
		The ID of the item that was changed
		@hibernate.property type="int"
		@hibernate.column name="`item_id`" not-null="true"
	*/
	public int getItemId()
	{
		return itemId;
	}
	public void setItemId(int itemId)
	{
		this.itemId = itemId;
	}

	private int itemType;
	/**
		The type code of the item that was changed.
		@hibernate.property type="int"
		@hibernate.column name="`item_type`" not-null="true"
	*/
	public int getItemType()
	{
		return itemType;
	}
	public void setItemType(int itemType)
	{
		this.itemType = itemType;
	}

	public static final int MAX_CHANGE_INFO_LENGTH = 65535;
	private String changeInfo;
	/**
		Get more information about this change.
		@hibernate.property column="`change_info`" type="text" not-null="false"
	*/
	public String getChangeInfo()
	{
		return changeInfo;
	}
	public void setChangeInfo(String changeInfo)
	{
		this.changeInfo = changeInfo;
	}


	
}
