/*
	$Id: ContextIndex.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.io.Serializable;

/**

	@author Nicklas
	@version 2.0
	@see <a href="../../../../../../html/developerdoc/api/data_api.clients.html">Session and client overview</a>
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (Mon, 06 Apr 2009) $
*/
@SuppressWarnings({"serial"})
public class ContextIndex
	implements Serializable
{
	ContextIndex()
	{}
	
	public ContextIndex(ClientData client, int itemType, String subContext, String name)
	{
		this.client = client;
		this.itemType = itemType;
		this.name = name;
		this.subContext = subContext;
	}

	private transient ClientData client;
	/**
		Get the client which uses this context.
		@hibernate.many-to-one column="`client_id`" update="false" insert="false"
	*/
	public ClientData getClient()
	{
		return client;
	}
	void setClient(ClientData client)
	{
		this.client = client;
	}

	private int itemType;
	/**
		@hibernate.property column="`item_type`" type="int" insert="false" update="false"
	*/
	public int getItemType()
	{
		return itemType;
	}
	void setItemType(int itemType)
	{
		this.itemType = itemType;
	}
	
	private String subContext;
	/**
		Get the subcontext this <code>Context</code> belongs to.
		@hibernate.property column="`subcontext`" type="string" length="255" insert="false" update="false"
	*/
	public String getSubContext()
	{
		return subContext;
	}
	void setSubContext(String subContext)
	{
		this.subContext = subContext;
	}

	private String name;
	/**
		Get the name of this <code>Context</code> item.
		@hibernate.property column="`name`" type="string" length="255" insert="false" update="false"
	*/
	public String getName()
	{
		return name;
	}
	void setName(String name)
	{
		this.name = name;
	}

	/**
		Check if this object is equal to another <code>ContextIndex</code>
		object. They are equal if both have the same client, item type and context type
	*/
	public boolean equals(Object o)
	{
		if ((o == null) || (getClass() != o.getClass()))
		{
			return false;
		}
		ContextIndex ci = (ContextIndex)o;
		return (this.client.equals(ci.client)) && (this.itemType == ci.itemType) && 
			(this.subContext.equals(ci.subContext)) && (this.name.equals(ci.name));
	}

	/**
		Calculate the hash code for the object.
	*/
	public int hashCode()
	{
		return (int)(127 * client.getId() + 53 * itemType + 31 * subContext.hashCode() + 17 * name.hashCode());
	}
}
