/**
	$Id: AnnotationFilter.java 5132 2009-10-14 11:55:03Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.snapshot;

import net.sf.basedb.core.Annotation;
import net.sf.basedb.util.filter.Filter;

/**
	Filter implementation that finds the annotation snapshot
	for a given annotation.

	@author Nicklas
	@version 2.14
	@base.modified $Date: 2009-10-14 13:55:03 +0200 (Wed, 14 Oct 2009) $
*/
public class AnnotationFilter
	implements Filter<AnnotationSnapshot>
{
	private int annotationId;
	
	/**
		Create a filter that matches all annotations.
	*/
	public AnnotationFilter()
	{}
	
	/**
		Create a filter that matches a specfic annotation.
	*/
	public AnnotationFilter(Annotation a)
	{
		this.annotationId = a.getId();
	}
	
	/*
		From the Filter interface
		-------------------------
	*/
	@Override
	public boolean evaluate(AnnotationSnapshot snapshot)
	{
		return snapshot.getAnnotationId() == annotationId || annotationId == 0;
	}
	// --------------------------

	/**
		Set the annotation this filter should match.
		@param a A specific annotation, or null to match any annotation
	*/
	public void setAnnotation(Annotation a)
	{
		this.annotationId = a == null ? 0 : a.getId();
	}

}
