/**
	$Id: SoftwareLoader.java 4740 2009-02-05 13:39:25Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;

import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.core.RawBioAssay;
import net.sf.basedb.core.Software;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for software. Software is loaded as
	end-point property nodes with no children. It can't be a root 
	node or a forward/reverse-loading node.
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-02-05 14:39:25 +0100 (Thu, 05 Feb 2009) $
*/
public class SoftwareLoader
	extends BasicItemNodeLoader<Software>
{

	public SoftwareLoader()
	{
		super(Item.SOFTWARE, DENY_ROOT_NODE, 
				new NameableNameGenerator<Software>("software", "Software"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		NodeFactory<Software> nf = getNodeFactory(dc, context);
		Software software = null;
		boolean denied = false;
		try
		{
			BasicItem parentItem = parentNode.getItem(dc);
			if (parentItem instanceof RawBioAssay)
			{
				software = ((RawBioAssay)parentItem).getSoftware();
			}
			// If there are other items with a software
			// we should add more cases here
		}
		catch (PermissionDeniedException ex)
		{
			denied = true;
		}
		Node softwareNode = createItemNode(nf, software, software, denied, 
				parentNode, ChildNodeDirection.NONE);
		return softwareNode;
	}
	// -----------------------------------
	
}
