/**
	$Id: NodeValidatorFactory.java 4864 2009-03-30 07:18:50Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.ItemNotFoundException;

/**
	A node validator factory is a class that know how to
	create {@link NodeValidator}:s for a given key domain.

	@author Nicklas
	@version 2.10
	@base.internal This class is still being developed. It may change 
		without notice in future versions of BASE.
	@base.modified $Date: 2009-03-30 09:18:50 +0200 (Mon, 30 Mar 2009) $
*/
public interface NodeValidatorFactory<L, K>
{

	/**
		Disable/enabled node validation programmatically. When a 
		node validator factory is disabled the {@link #createNodeValidator(Object)}
		should return null or a {@link NullNodeValidator} for all
		requests.
		@param disabled TRUE to disable node validation
		@since 2.11
	*/
	public void setDisabled(boolean disabled);
	
	/**
		Check if node validation has been disabled.
		@return TRUE if validation has been disabled
		@since 2.11
	*/
	public boolean isDisabled();
	
	/**
		Create a node validator that knows how to validate nodes for items
		that are specified by the given key. The key can be almost anything.
		The interpretation of it is entirely up to the factory implementation.
		
		@param key A key that can be used to identify which items the node
			validator should handle
		@return A node validator object, or null if no validator exists
		@throws ItemNotFoundException If a node loader for the given key 
			can't be found. NOTE! Instead of throwing an exception it is possible
			to simply return null or a {@link NullNodeValidator} or any other 
			"generic" implementation.
		@throws BaseException If there is any other problem creating the
			node validator
	*/
	public NodeValidator<? extends L> createNodeValidator(K key);

}
