import java.util.Date;

import net.sf.basedb.core.*;

/*
 $Id: TestExtraValueType.java 5060 2009-08-19 07:02:11Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

 BASE is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3
 of the License, or (at your option) any later version.

 BASE is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with BASE. If not, see <http://www.gnu.org/licenses/>.
 */

public class TestExtraValueType
{
	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing extra value types");
		write_header();
		// Standard tests: create, load, list
		int intId = test_create("test.int", Type.INT, true);
		int floatId = test_create("test.float", Type.FLOAT, true);
		int stringId = test_create("test.string", Type.STRING, true);
		test_load(intId);
		test_list();

		// Extra tests:

		// Standard test: Delete
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();
		test_delete(intId);
		test_delete(floatId);
		test_delete(stringId);
		write("++Testing extra value types "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static int test_create(String externalId, Type valueType, boolean setAll)
	{
		if (!TestUtil.hasPermission(Permission.CREATE, Item.EXTRAVALUETYPE)) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ExtraValueType evt = ExtraValueType.getNew(dc, externalId, valueType);
			if (setAll)
			{
				evt.setName("Test extra value of type " + valueType);
				evt.setDescription("Added at "+new Date());
			}
			dc.saveItem(evt);
			dc.commit();
			id = evt.getId();
			dc = TestUtil.getDbControl();
			dc.reattachItem(evt, false);
			write_item(0, evt);
			write("--Create extra value type OK");
		}
		catch (Throwable ex)
		{
			write("--Create extra value type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}

	static void test_load(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ExtraValueType evt = ExtraValueType.getById(dc, id);
			write_item(0, evt);
			write("--Load extra value type OK");
		}
		catch (Throwable ex)
		{
			write("--Load extra value type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void test_list()
	{
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ItemResultList<ExtraValueType> l = ExtraValueType.getQuery().list(dc);
			for (int i = 0; i<l.size(); i++)
			{
				write_item(i, l.get(i));
			}
			write("--List extra value types OK ("+l.size()+")");
		}
		catch (Throwable ex)
		{
			write("--List extra value types FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void test_delete(int id)
	{
		if (id == 0) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			ExtraValueType evt = ExtraValueType.getById(dc, id);
			dc.deleteItem(evt);
			dc.commit();
			write("--Delete extra value type OK");
		}
		catch (Throwable ex)
		{
			write("--Delete extra value type FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}

	static void write_header()
	{
		if (!TestUtil.getSilent())
		{
			write("   \tID \tName      \tDescription\tValue type\tExternal id");
			write("-- \t-- \t--------- \t-----------\t----------\t-----------");
		}
	}
	static void write_item(int i, ExtraValueType evt)
		throws BaseException
	{
		if (!TestUtil.getSilent()) System.out.println(i+":\t"+evt.getId()+"\t"+evt.getName()+"\t"+
			evt.getDescription()+"\t"+evt.getValueType()+"\t"+evt.getExternalId());
	}
	static void write(String message)
	{
		System.out.println(message);
	}
}
