/**
	$Id: SessionService.java 4513 2008-09-11 20:06:36Z jari $

	Copyright (C) 2007 Martin Svensson, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.ws.server;

import net.sf.basedb.core.Application;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.info.VersionInfo;

/**
 	Web service class for Session in BASE 
 	{@link net.sf.basedb.core.Session}
  	@author Nicklas, Martin
  	@version 2.5
 */
public class SessionService
	extends AbstractRPCService
{
	/**
	 	
	 */
	public SessionService()
	{}
	
	/**
	 	Creates a new session control.
	  	@param externalClientId The external id of a BASE client, or null if
	  		the application hasn't been registered as a client application
	  	@return Session id as a String
	 */
	public String newSession(String externalClientId)
	{
		SessionControl sc = Application.newSessionControl(externalClientId, getRemoteId(), null);
		return sc.getId();
	}

	/**
	 	Service for net.sf.basedb.core.SessionControl#getChallenge()
	  	@param ID
	  	@return String A radom string
	 */
	public String getChallenge(String ID)
	{
		SessionControl sc = getSessionControl(ID);
		return sc.getChallenge();
	}
	
	/**
	 	Service to login to BASE
	  	@param ID Id of a session control
	  	@param login Login name for the account to use
	  	@param password Password for the login above.
	  	@param comment Comment to be used with the new session
	  	@param encrypted If encrypted password should be used or not.
	  	@return The Session ID
	 */
	public String login(String ID, String login, String password, String comment, boolean encrypted)
	{
		SessionControl sc = getSessionControl(ID);
		sc.login(login, password, comment, encrypted);
		return ID;
	}
	
	/**
	 	Service to logout from BASE
	  	@param ID Id of the session to logout.
	  	@return The Session ID
	 */
	public String logout(String ID)
	{
		SessionControl sc = getSessionControl(ID);
		sc.logout();
		return ID;
	}
	
	/**
	 	Gets the time in minutes when a session 
	 	is automatically logged out.
	  	@return An integer with number of minutes
	*/
	public Integer getSessionTimeOut()
	{
		return Application.sessionCacheTimeout();
	}
	
	/**
	 	Refresh a session so the time for logging out will be reset.
	  	@param ID The session id as a string
	  	@return The Session ID
	 */
	public String refreshSession(String ID)
	{
		SessionControl sc = getSessionControl(ID);
		sc.updateLastAccess();
		return ID;
	}
	
	/**
	 	Return information about which Base version is in use.

	  	@return A {@link VersionInfo} object
	 */
	public VersionInfo getVersion()
	{
		VersionInfo info = new VersionInfo();
		info.setMajor(Application.getMajorVersion());
		info.setMinor(Application.getMinorVersion());
		info.setMaintenance(Application.getMaintenanceVersion());
		info.setBuild(Application.getBuild());
		info.setSchema(Application.getSchemaVersion());
		return info;
	}
}
