/* $Id: annotations.js 2584 2006-08-24 07:58:05Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Nicklas Nordborg
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	JavaScript functions for sending Ajax request. Create a
	request with Main.getAjaxRequest() or Ajax.getXmlHttpRequest().

	@author Nicklas
	@version 2.0
*/

var Ajax = new AjaxClass();
function AjaxClass()
{
	/**
		Create a new ajax request.
		@return A request object or null if the browser doesn't support ajax
	*/
	this.getXmlHttpRequest = function()
	{
		return Main.getAjaxRequest();
	}
	
	/**
		Register callback functions for a successful of failed request.
		When the request has been completed, the onSuccessHandler or
		onFailHandler will be called with the request as a parameter:
		onSuccessHandler(request);
	*/
	this.setReadyStateHandler = function(request, onSuccessHandler, onFailHandler)
	{
		request.onreadystatechange = function()
		{
			if (request.readyState == 4)
			{
				if (request.status == 200 && onSuccessHandler)
				{
					onSuccessHandler(request);
				}
				else if (onFailHandler)
				{
					onFailHandler(request);
				}
			}
		}
	}
	
	this.parseResponse = function(responseText)
	{
		var lines = responseText.split(/\n/);
		var elements = new Array();
		var status = null;
		var element = null;
		
		var keyValueRegexp = new RegExp('(\\w+)\\:(.*)');
		var newLineRegexp = new RegExp('\\\\n', 'g');
		for (var i = 0; i < lines.length; i++)
		{
			var line = lines[i];
			if (line == '')
			{
				if (element != null) elements[elements.length] = element;
				element = null;
			}
			else if (i == 0 && line.indexOf('status:') == 0)
			{
				status = line.substring(7);
			}
			else
			{
				var kv = line.match(keyValueRegexp);
				if (kv != null)
				{
					var key = kv[1];
					var value = kv[2];
					value = value.replace(newLineRegexp, '\n');
					if (element == null) element = new Array();
					var exists = element[key];
					var isArray = element[key] instanceof Array;
					if (!exists)
					{
						element[key] = value;
					}
					else
					{
						if (!isArray)
						{
							// Convert to array
							var tmp = new Array();
							tmp[0] = element[key];
							element[key] = tmp;
						}
						var tmp = element[key];
						tmp[tmp.length] = value;
					}
				}
			}
		}
		if (element != null) elements[elements.length] = element;
		return new AjaxResponse(status, elements);
	}
	
}

function AjaxResponse(status, elements)
{
	this.status = status;
	this.elements = elements;
	
	this.getStatus = function()
	{
		return status;
	}
	
	this.isError = function()
	{
		return status == 'error';
	}
	
	this.getErrorMessage = function()
	{
		return this.isError() ? elements[0]['message'] : '';
	}
	
	this.getElements = function()
	{
		return elements;
	}
	
}

